==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AdvancedSettings</name>
    <message>
        <source>Menu Configuration</source>
        <translation type="vanished">Configurazione del menu</translation>
    </message>
    <message>
        <source>Notification Duration</source>
        <translation type="vanished">Durata delle notifiche</translation>
    </message>
    <message>
        <source>For some the notification&apos;s expiration time is dependent on the notification server&apos;s settings.</source>
        <translation type="vanished">Per alcune notifiche il tempo dipende dalle impostazioni del server delle notifiche.</translation>
    </message>
    <message>
        <source>&quot;Server Decides&quot; Time:</source>
        <translation type="vanished">Tempo di decisioni del server:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Distanza:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Alcune notifiche impostano una durata propria.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Durata di default:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Notification Spacing:</source>
        <translatorcomment>a cosa si riferisce??</translatorcomment>
        <translation type="obsolete">Spazing:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <source>Notification Width:</source>
        <translation type="vanished">Larghezza:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Impostazioni base</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Posizione sullo schermo</translation>
    </message>
    <message>
        <source>Display Notifications</source>
        <translation type="vanished">Mostra notifiche</translation>
    </message>
    <message>
        <source>Top/Left</source>
        <translation type="vanished">Alto a sinistra</translation>
    </message>
    <message>
        <source>Top/Right</source>
        <translation type="vanished">Alto a destra</translation>
    </message>
    <message>
        <source>Bottom/Left</source>
        <translation type="vanished">Fondo a sinistra</translation>
    </message>
    <message>
        <source>Bottom/Right</source>
        <translation type="vanished">Fondo a destra</translation>
    </message>
    <message>
        <source>Test Notification</source>
        <translation type="vanished">Notifica di prova</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Attenzione:&lt;/b&gt; Nessun demone di notifiche è in esecuzione.
Sarà usato un sistema di riserva.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Avviso:&lt;/b&gt; Un altro demone di notifiche (%1) è attivo.
Queste impostazioni non avranno effetto per lui!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation>Anteprima notifiche </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Questo è una notifica di test.
Tutte le notifiche di LXQt appariranno qui.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have an effect on it!</source>
        <translation type="vanished">&lt;b&gt;Attenzione:&lt;/b&gt; Un altro demone di notifiche (%1) è in esecuzione.
Queste impostazioni non avranno effetto su quello!</translation>
    </message>
    <message>
        <source>Notification Summary</source>
        <translation type="vanished">Sommario della notifica</translation>
    </message>
    <message>
        <source>Notification Body</source>
        <translation type="vanished">Corpo della notifica</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Notificazioni Desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Impostazioni base</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Impostazioni avanzate</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AdvancedSettings</name>
    <message>
        <source>Menu Configuration</source>
        <translation type="vanished">Configurazione del menu</translation>
    </message>
    <message>
        <source>Notification Duration</source>
        <translation type="vanished">Durata delle notifiche</translation>
    </message>
    <message>
        <source>For some the notification&apos;s expiration time is dependent on the notification server&apos;s settings.</source>
        <translation type="vanished">Per alcune notifiche il tempo dipende dalle impostazioni del server delle notifiche.</translation>
    </message>
    <message>
        <source>&quot;Server Decides&quot; Time:</source>
        <translation type="vanished">Tempo di decisioni del server:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Distanza:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Alcune notifiche impostano una durata propria.</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Durata di default:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Notification Spacing:</source>
        <translatorcomment>a cosa si riferisce??</translatorcomment>
        <translation type="obsolete">Spazing:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="32"/>
        <location filename="../../../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <source>Notification Width:</source>
        <translation type="vanished">Larghezza:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Impostazioni base</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Posizione sullo schermo</translation>
    </message>
    <message>
        <source>Display Notifications</source>
        <translation type="vanished">Mostra notifiche</translation>
    </message>
    <message>
        <source>Top/Left</source>
        <translation type="vanished">Alto a sinistra</translation>
    </message>
    <message>
        <source>Top/Right</source>
        <translation type="vanished">Alto a destra</translation>
    </message>
    <message>
        <source>Bottom/Left</source>
        <translation type="vanished">Fondo a sinistra</translation>
    </message>
    <message>
        <source>Bottom/Right</source>
        <translation type="vanished">Fondo a destra</translation>
    </message>
    <message>
        <source>Test Notification</source>
        <translation type="vanished">Notifica di prova</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Attenzione:&lt;/b&gt; Nessun demone di notifiche è in esecuzione.
Sarà usato un sistema di riserva.</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Avviso:&lt;/b&gt; Un altro demone di notifiche (%1) è attivo.
Queste impostazioni non avranno effetto per lui!</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation>Anteprima notifiche </translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Questo è una notifica di test.
Tutte le notifiche di LXQt appariranno qui.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have an effect on it!</source>
        <translation type="vanished">&lt;b&gt;Attenzione:&lt;/b&gt; Un altro demone di notifiche (%1) è in esecuzione.
Queste impostazioni non avranno effetto su quello!</translation>
    </message>
    <message>
        <source>Notification Summary</source>
        <translation type="vanished">Sommario della notifica</translation>
    </message>
    <message>
        <source>Notification Body</source>
        <translation type="vanished">Corpo della notifica</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Notificazioni Desktop</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Impostazioni base</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Impostazioni avanzate</translation>
    </message>
</context>
</TS>
